@@ -51,11 +51,10 @@ else
     exit 1
 fi
 
-# Store PostgreSQL password in config
-echo "Updating configuration..."
-echo "" >> /docker/whp/web/configs/config.php
-echo "// PostgreSQL Configuration" >> /docker/whp/web/configs/config.php
-echo "define('POSTGRES_PASS', '$postgres_password');" >> /docker/whp/web/configs/config.php
+# Store PostgreSQL login details in .pgpass format
+echo "Storing PostgreSQL credentials..."
+echo "127.0.0.1:5432:*:postgres:$postgres_password" > /root/.pgpass
+chmod 600 /root/.pgpass
 
 # Install PostgreSQL PHP module
 echo "Installing PostgreSQL PHP module..."
@@ -65,41 +64,19 @@ dnf install -y php-pgsql
 echo "Restarting PHP-FPM to load PostgreSQL module..."
 systemctl restart php-fpm
 
-# Install pgAdmin 4 via RPM
-echo "Installing pgAdmin 4..."
-dnf install -y https://ftp.postgresql.org/pub/pgadmin/pgadmin4/yum/pgadmin4-redhat-repo-2-1.noarch.rpm
-dnf install -y pgadmin4-web
-
-# Install required Python module for pgAdmin setup
-echo "Installing required Python modules for pgAdmin..."
-pip3 install typer
-
-# Configure pgAdmin
-echo "Configuring pgAdmin 4..."
-PGADMIN_SETUP_EMAIL='admin@localhost' PGADMIN_SETUP_PASSWORD="$postgres_password" /usr/pgadmin4/bin/setup-web.sh --yes
-if [ $? -eq 0 ]; then
-    echo "✓ pgAdmin 4 setup completed successfully"
+# Download Adminer for database management
+echo "Installing Adminer for database management..."
+if ! wget -q -O /docker/whp/web/adminer.php "https://www.adminer.org/latest.php"; then
+    echo "⚠ Failed to download latest Adminer, trying alternative URL..."
+    if ! wget -q -O /docker/whp/web/adminer.php "https://github.com/vrana/adminer/releases/download/v4.8.1/adminer-4.8.1.php"; then
+        echo "⚠ Failed to download Adminer - database management interface may not work"
+    else
+        echo "✓ Adminer downloaded successfully (fallback version)"
+    fi
 else
-    echo "⚠ pgAdmin 4 setup failed - continuing anyway"
+    echo "✓ Adminer downloaded successfully (latest version)"
 fi
 
-# Configure Apache for pgAdmin
-cat > /etc/httpd/conf.d/pgadmin4.conf << 'EOF'
-LoadModule wsgi_module modules/mod_wsgi_python3.so
-WSGIDaemonProcess pgadmin processes=1 threads=25 python-home=/usr/pgadmin4/venv
-WSGIScriptAlias /pgadmin4 /usr/pgadmin4/web/pgAdmin4.wsgi
-
-<Directory /usr/pgadmin4/web/>
-    WSGIProcessGroup pgadmin
-    WSGIApplicationGroup %{GLOBAL}
-    Require all granted
-</Directory>
-EOF
-
-# Set proper permissions
-chown -R root:root /var/lib/pgadmin
-chown -R root:root /var/log/pgadmin
-
 # Apply database migrations
 echo "Applying database migrations..."
 mysql < /root/whp/sql/migrations/staging/001_postgresql_support.sql
@@ -113,7 +90,7 @@ echo "Updating permissions..."
 sed -i "/'database-management' => array('all'), \/\/ All authenticated users/a\        'postgresql-management' => array('all'), \/\/ All authenticated users" /docker/whp/web/libs/permission_manager.php
 sed -i "/'database-management' => array('all'),$/a\        'postgresql-management' => array('all')," /docker/whp/web/libs/permission_manager.php
 
-# Restart Apache to load pgAdmin
+# Restart Apache to apply changes
 echo "Restarting Apache..."
 systemctl restart httpd
 
@@ -128,11 +105,11 @@ echo "- Host: 127.0.0.1"
 echo "- Port: 5432"
 echo "- Username: postgres"
 echo "- Password: $postgres_password"
+echo "- Credentials stored in: /root/.pgpass"
 echo ""
-echo "pgAdmin 4 Access:"
-echo "- URL: https://your-server/pgadmin4"
-echo "- Email: admin@localhost"
-echo "- Password: $postgres_password"
+echo "Database Management:"
+echo "- Adminer is available via the WHP interface"
+echo "- PostgreSQL Management page provides full database management"
 echo ""
 echo "PostgreSQL container status:"
 docker ps | grep postgresql >/dev/null 2>&1 && echo "✓ PostgreSQL container is running" || echo "✗ PostgreSQL container is not running"
